<?php

namespace IMMIGROPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Event_Slider extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'immigro_event_slider';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Event Slider', 'immigro' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'immigro' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'event_slider',
			[
				'label' => esc_html__( 'Event Slider', 'immigro' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Slider Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[	

									'block_image'=>		
									[
									'name' => 'block_image',
									'label' => __( 'Image', 'rashid' ),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								  	],	

									  'block_alt_text'=>		
									[
									'name' => 'block_alt_text',
									'label' => esc_html__('Alt Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('iamge', 'rashid')
									],

										'block_bgimg'=>		
									[
										'name' => 'block_bgimg',
										'label' => esc_html__('Background Shape', 'rashid'),
										'type' => Controls_Manager::MEDIA,
										'default' => ['url' => Utils::get_placeholder_image_src(),],
									],
																		
										'block_title'=>	
									[
										'name' => 'block_title',
										'label' => esc_html__('Date', 'rashid'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'rashid')
									],

									'block_title1'=>	
									[
										'name' => 'block_title1',
										'label' => esc_html__('Title', 'rashid'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'rashid')
									],	

									'block_text'=>
									
									[
										'name' => 'block_text',
										'label' => esc_html__('Text', 'rashid'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'rashid')
									],

									'block_icons'=>

									[
										'name' => 'block_icons',
										'label' => esc_html__('Enter The icons', 'rashid'),
										'type' => Controls_Manager::ICONS,							
									],

									'block_text1'=>
									
									[
										'name' => 'block_text1',
										'label' => esc_html__('Time', 'rashid'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'rashid')
									],

									'block_icons1'=>

									[
										'name' => 'block_icons1',
										'label' => esc_html__('Enter The icons', 'rashid'),
										'type' => Controls_Manager::ICONS,							
									],

									'block_text2'=>
									
									[
										'name' => 'block_text2',
										'label' => esc_html__('Location', 'rashid'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'rashid')
									],

									'block_button'=>

									[
										'name' => 'block_button',
										'label'       => __( 'Button', 'rashid' ),
										'type'        => Controls_Manager::TEXT,
										'dynamic'     => [
											'active' => true,
										],
										'placeholder' => __( 'Enter your Button Title', 'rashid' ),
										'default' => esc_html__('Read More', 'rashid'),
									],

									'block_btnlink'=>
									
									[
									  'name' => 'block_btnlink',
									  'label' => __( 'Button Url', 'rashid' ),
									  'type' => Controls_Manager::URL,
									  'placeholder' => __( 'https://your-link.com', 'rashid' ),
									  'show_external' => true,
									  'default' => [
										'url' => '',
										'is_external' => true,
										'nofollow' => true,
									  ],
								   ],
							
											
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
					
		
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>



<?php
	  echo '
	 <script>
 jQuery(document).ready(function($)
 {

//put the js code under this line 

if ($(".single-item-carousel").length) {
	$(".single-item-carousel").owlCarousel({
		loop:true,
		margin:30,
		nav:true,
		smartSpeed: 500,
		autoplay: 1000,
		responsive:{
			0:{
				items:1
			},
			480:{
				items:1
			},
			600:{
				items:1
			},
			800:{
				items:1
			},			
			1200:{
				items:1
			}

		}
	});    		
}

//put the code above the line 

  });
</script>';


?>

	<section class="team-area pt-130 pb-130">
        <div class="container">
            <div class="row align-items-center">
                <div class="col-lg-5">
                    <div class="team-title">
                        <h3 class="title"><?php echo $settings['title'];?></h3>
                        <span><?php echo $settings['subtitle'];?></span>
                    </div>
                </div>
                <div class="col-lg-7">
                    <div class="row team-active">
                        
						<div class="col-lg-6">
                            <div class="team-item">
                                <div class="team-overlay">
                                    <div class="team-contet text-center">
										<ul>
											<li><a href="<?php echo cloven_set( $header_social_icons, 'url' ); ?>"><i class="fab <?php echo esc_attr( cloven_set( $header_social_icons, 'icon' ) ); ?>"></i></a></li>
										</ul>
                                        <h5 class="title"><?php the_title(); ?></h5>
                                        <span><?php echo (get_post_meta( get_the_id(), 'designation', true ));?></span>
                                    </div>
                                </div>
                            </div>
                        </div>
                         
                    </div>
                </div>
            </div>
        </div>
    </section>	
             
		<?php 
	}

}